==> cleantalk-8.x-1.8.tar.gz: cleantalk/src/CleantalkSFW.php <==
<?php
namespace Drupal\cleantalk;
/**
Cleantalk Spam FireWall class
**/

class CleanTalkSFW
{
	public $ip = 0;
	public $ip_str = '';
	public $ip_array = Array();
	public $ip_str_array = Array();
	public $blocked_ip = '';
	public $passed_ip = '';
	public $result = false;
	
	public function cleantalk_get_real_ip()
	{
		if ( function_exists( 'apache_request_headers' ) )
		{
			$headers = apache_request_headers();
		}
		else
		{
			$headers = $_SERVER;
		}
		
		$the_ip = filter_var( $_SERVER['REMOTE_ADDR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 );
		$this->ip_str_array[]=$the_ip;
		$this->ip_array[]=sprintf("%u", ip2long($the_ip));
		
		if ( array_key_exists( 'X-Forwarded-For', $headers ) ){
			$the_ip=explode(",", trim($headers['X-Forwarded-For']));
			$the_ip = trim($the_ip[0]);
			$this->ip_str_array[]=$the_ip;
			$this->ip_array[]=sprintf("%u", ip2long($the_ip));
		}
		
		if ( array_key_exists( 'HTTP_X_FORWARDED_FOR', $headers )){
			$the_ip=explode(",", trim($headers['HTTP_X_FORWARDED_FOR']));
			$the_ip = trim($the_ip[0]);
			$this->ip_str_array[]=$the_ip;
			$this->ip_array[]=sprintf("%u", ip2long($the_ip));
		}

		if(isset($_GET['sfw_test_ip'])){
			$the_ip=$_GET['sfw_test_ip'];
			$this->ip_str_array[]=$the_ip;
			$this->ip_array[]=sprintf("%u", ip2long($the_ip));
		}
	}
	/**
	 * Function sends raw request to API server
	 *
	 * @param string url of API server
	 * @param array data to send
	 * @param boolean is data have to be JSON encoded or not
	 * @param integer connect timeout
	 * @return type
	 */

	public function sendRawRequest($url,$data,$isJSON=false,$timeout=3) {
	    $result=null;
	    if(!$isJSON) {
	        $data=http_build_query($data);
	    }
	    else {
	        $data= \Drupal\Component\Serialization\Json::encode($data);
	    }
	    $curl_exec=false;
	    if (function_exists('curl_init')) {
	    
	        $ch = curl_init();
	        curl_setopt($ch, CURLOPT_URL, $url);
	        curl_setopt($ch, CURLOPT_TIMEOUT, $timeout);
	        curl_setopt($ch, CURLOPT_POST, true);
	        curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
	        
	        // receive server response ...
	        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	        // resolve 'Expect: 100-continue' issue
	        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Expect:'));
	        
	        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
	        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
	        
	        $result = @curl_exec($ch);
	        if($result!==false) {
	            $curl_exec=true;
	        }
	        @curl_close($ch);
	    }
	    if(!$curl_exec) {
	        $opts = array(
	            'http'=>array(
	                'method'=>"POST",
	                'content'=>$data)
	        );
	        $context = stream_context_create($opts);
	        $result = @file_get_contents($url, 0, $context);
	    }
	    return $result;
	}	
	public function check_ip()
	{				
		$r = \Drupal::service('database')->query("SHOW TABLES LIKE '{cleantalk_sfw}'");
		$ob = $r->fetchObject();
		if(isset($ob) && is_object($ob)){
			for($i=0;$i<sizeof($this->ip_array);$i++){
				$r = \Drupal::service('database')->query("select count(network) as cnt from `{cleantalk_sfw}` where network = ".$this->ip_array[$i]." & mask;");
					$cnt = intval($r->fetchObject()->cnt);
				if($cnt>0)
				{
					$this->result=true;
					$this->blocked_ip=$this->ip_str_array[$i];
				}
				else
				{
					$this->passed_ip = $this->ip_str_array[$i];
				}
			}
		}
		if($this->passed_ip != '')
		{
			$key = \Drupal::config('cleantalk.settings')->get('cleantalk_authkey');
			@setcookie ('ct_sfw_pass_key', md5($this->passed_ip . $key), 0, "/");
		}
	}
	
	public function sfw_die()
	{
		$key=\Drupal::config('cleantalk.settings')->get('cleantalk_authkey');
		$sfw_die_page=file_get_contents(dirname(__FILE__)."/sfw_die_page.html");
		$sfw_die_page=str_replace("{REMOTE_ADDRESS}",$this->blocked_ip,$sfw_die_page);
		$sfw_die_page=str_replace("{REQUEST_URI}",$_SERVER['REQUEST_URI'],$sfw_die_page);
		$sfw_die_page=str_replace("{SFW_COOKIE}",md5($this->blocked_ip.$key),$sfw_die_page);
		@setcookie ('ct_sfw_passed', '0');
		@header('HTTP/1.0 403 Forbidden');
		print $sfw_die_page;
		die();
	}
	
	static public function sfw_update($ct_key){		
		$data = Array();
		$method_name = '2s_blacklists_db';
		$result=self::sendRawRequest("https://api.cleantalk.org/?auth_key=$ct_key&method_name=$method_name",$data,false);
						
		$result=json_decode($result, true);
		
		if(isset($result['data'])){

			\Drupal::service('database')->query("TRUNCATE TABLE `{cleantalk_sfw}`");
			
			$result=$result['data'];
			$query="INSERT INTO `{cleantalk_sfw}` VALUES ";
			for($i=0;$i<sizeof($result);$i++){
				if($i==sizeof($result)-1){
					$query.="(".$result[$i][0].",".$result[$i][1].");";
				}else{
					$query.="(".$result[$i][0].",".$result[$i][1]."), ";
				}
			}
			$result = \Drupal::service('database')->query($query);
		}
	}
	
	//Add entries to SFW log
	static public function sfw_update_logs($ip, $result){
		if($ip === NULL || $result === NULL){
			error_log('SFW log update failed');
			return;
		}
		
		$blocked = ($result == 'blocked' ? ' + 1' : '');
		$time = time();

		$query = "INSERT INTO `{cleantalk_sfw_logs}`
		SET 
			`ip` = '$ip',
			`all_entries` = 1,
			`blocked_entries` = 1,
			`entries_timestamp` = '".$time."'
		ON DUPLICATE KEY 
		UPDATE 
			`all_entries` = `all_entries` + 1,
			`blocked_entries` = `blocked_entries`".$blocked.",
			`entries_timestamp` = '".$time."'";

		$result = \Drupal::service('database')->query($query);		
	}
	
	//Send and wipe SFW log
	public static function send_logs($ct_key){
		
		//Getting logs		
		$result = db_select('{cleantalk_sfw_logs}', 'ct_sfw')
			->fields('ct_sfw')
			->execute()
			->fetchAll();
				
		if(!empty($result)){
			
			// Compile logs
			$data = array();
			foreach($result as $key => $value){
				$data[] = array(trim($value->ip), (int)$value->all_entries, (int)($value->all_entries - $value->blocked_entries), (int)$value->entries_timestamp);
			} unset($key, $value, $result);
			
			//Final compile
			$qdata = array (
				'data' => json_encode($data),
				'rows' => count($data),
				'timestamp' => time()
			);
			
			//Sendings request
			$result=self::sendRawRequest('https://api.cleantalk.org/?method_name=sfw_logs&auth_key='.$ct_key, $qdata, false);
			
			$result = json_decode($result);
			//Checking answer and truncate table, reset counter
			if(isset($result->data) && isset($result->data->rows))
				if($result->data->rows == count($data)){
					\Drupal::service('database')->query("TRUNCATE TABLE `{cleantalk_sfw_logs}`");
				}
		}
	}
}
?>

==> cleantalk-8.x-2.0.tar.gz: cleantalk/src/CleantalkSFW.php <==
<?php
namespace Drupal\cleantalk;
/**
Cleantalk Spam FireWall class
**/

class CleantalkSFW
{
	public $ip = 0;
	public $ip_str = '';
	public $ip_array = Array();
	public $ip_str_array = Array();
	public $blocked_ip = '';
	public $passed_ip = '';
	public $result = false;
	
	public function cleantalk_get_real_ip()
	{
		if ( function_exists( 'apache_request_headers' ) )
		{
			$headers = apache_request_headers();
		}
		else
		{
			$headers = $_SERVER;
		}
		
		$the_ip = filter_var( $_SERVER['REMOTE_ADDR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 );
		$this->ip_str_array[]=$the_ip;
		$this->ip_array[]=sprintf("%u", ip2long($the_ip));
		
		if ( array_key_exists( 'X-Forwarded-For', $headers ) ){
			$the_ip=explode(",", trim($headers['X-Forwarded-For']));
			$the_ip = trim($the_ip[0]);
			$this->ip_str_array[]=$the_ip;
			$this->ip_array[]=sprintf("%u", ip2long($the_ip));
		}
		
		if ( array_key_exists( 'HTTP_X_FORWARDED_FOR', $headers )){
			$the_ip=explode(",", trim($headers['HTTP_X_FORWARDED_FOR']));
			$the_ip = trim($the_ip[0]);
			$this->ip_str_array[]=$the_ip;
			$this->ip_array[]=sprintf("%u", ip2long($the_ip));
		}

		if(isset($_GET['sfw_test_ip'])){
			$the_ip=$_GET['sfw_test_ip'];
			$this->ip_str_array[]=$the_ip;
			$this->ip_array[]=sprintf("%u", ip2long($the_ip));
		}
	}
	/**
	 * Function sends raw request to API server
	 *
	 * @param string url of API server
	 * @param array data to send
	 * @param boolean is data have to be JSON encoded or not
	 * @param integer connect timeout
	 * @return type
	 */

	public function sendRawRequest($url,$data,$isJSON=false,$timeout=3) {
	    $result=null;
	    if(!$isJSON) {
	        $data=http_build_query($data);
	    }
	    else {
	        $data= \Drupal\Component\Serialization\Json::encode($data);
	    }
	    $curl_exec=false;
	    if (function_exists('curl_init')) {
	    
	        $ch = curl_init();
	        curl_setopt($ch, CURLOPT_URL, $url);
	        curl_setopt($ch, CURLOPT_TIMEOUT, $timeout);
	        curl_setopt($ch, CURLOPT_POST, true);
	        curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
	        
	        // receive server response ...
	        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	        // resolve 'Expect: 100-continue' issue
	        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Expect:'));
	        
	        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
	        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
	        
	        $result = @curl_exec($ch);
	        if($result!==false) {
	            $curl_exec=true;
	        }
	        @curl_close($ch);
	    }
	    if(!$curl_exec) {
	        $opts = array(
	            'http'=>array(
	                'method'=>"POST",
	                'content'=>$data)
	        );
	        $context = stream_context_create($opts);
	        $result = @file_get_contents($url, 0, $context);
	    }
	    return $result;
	}	
	public function check_ip()
	{				
		$r = \Drupal::service('database')->query("SHOW TABLES LIKE '{cleantalk_sfw}'");
		$ob = $r->fetchObject();
		if(isset($ob) && is_object($ob)){
			for($i=0;$i<sizeof($this->ip_array);$i++){
				$r = \Drupal::service('database')->query("select count(network) as cnt from `{cleantalk_sfw}` where network = ".$this->ip_array[$i]." & mask;");
					$cnt = intval($r->fetchObject()->cnt);
				if($cnt>0)
				{
					$this->result=true;
					$this->blocked_ip=$this->ip_str_array[$i];
				}
				else
				{
					$this->passed_ip = $this->ip_str_array[$i];
				}
			}
		}
		if($this->passed_ip != '')
		{
			$key = \Drupal::config('cleantalk.settings')->get('cleantalk_authkey');
			@setcookie ('apbct_sfw_pass_key', md5($this->passed_ip . $key), 0, "/");
		}
	}
	
	public function sfw_die()
	{
		$key=\Drupal::config('cleantalk.settings')->get('cleantalk_authkey');
		$sfw_die_page=file_get_contents(dirname(__FILE__)."/sfw_die_page.html");
		$sfw_die_page=str_replace("{REMOTE_ADDRESS}",$this->blocked_ip,$sfw_die_page);
		$sfw_die_page=str_replace("{REQUEST_URI}",$_SERVER['REQUEST_URI'],$sfw_die_page);
		$sfw_die_page=str_replace("{SFW_COOKIE}",md5($this->blocked_ip.$key),$sfw_die_page);
		@setcookie ('apbct_sfw_passed', '0');
		@header('HTTP/1.0 403 Forbidden');
		print $sfw_die_page;
		die();
	}
	
	static public function sfw_update($ct_key){		
		$data = Array();
		$method_name = '2s_blacklists_db';
		$result=self::sendRawRequest("https://api.cleantalk.org/?auth_key=$ct_key&method_name=$method_name",$data,false);
						
		$result=json_decode($result, true);
		
		if(isset($result['data'])){

			\Drupal::service('database')->query("TRUNCATE TABLE `{cleantalk_sfw}`");
			
			$result=$result['data'];
			$query="INSERT INTO `{cleantalk_sfw}` VALUES ";
			for($i=0;$i<sizeof($result);$i++){
				if($i==sizeof($result)-1){
					$query.="(".$result[$i][0].",".$result[$i][1].");";
				}else{
					$query.="(".$result[$i][0].",".$result[$i][1]."), ";
				}
			}
			$result = \Drupal::service('database')->query($query);
		}
	}
	
	//Add entries to SFW log
	static public function sfw_update_logs($ip, $result){
		if($ip === NULL || $result === NULL){
			error_log('SFW log update failed');
			return;
		}
		
		$blocked = ($result == 'blocked' ? ' + 1' : '');
		$time = time();

		$query = "INSERT INTO `{cleantalk_sfw_logs}`
		SET 
			`ip` = '$ip',
			`all_entries` = 1,
			`blocked_entries` = 1,
			`entries_timestamp` = '".$time."'
		ON DUPLICATE KEY 
		UPDATE 
			`all_entries` = `all_entries` + 1,
			`blocked_entries` = `blocked_entries`".$blocked.",
			`entries_timestamp` = '".$time."'";

		$result = \Drupal::service('database')->query($query);		
	}
	
	//Send and wipe SFW log
	public static function send_logs($ct_key){
		
		//Getting logs		
		$result = db_select('{cleantalk_sfw_logs}', 'ct_sfw')
			->fields('ct_sfw')
			->execute()
			->fetchAll();
				
		if(!empty($result)){
			
			// Compile logs
			$data = array();
			foreach($result as $key => $value){
				$data[] = array(trim($value->ip), (int)$value->all_entries, (int)($value->all_entries - $value->blocked_entries), (int)$value->entries_timestamp);
			} unset($key, $value, $result);
			
			//Final compile
			$qdata = array (
				'data' => json_encode($data),
				'rows' => count($data),
				'timestamp' => time()
			);
			
			//Sendings request
			$result=self::sendRawRequest('https://api.cleantalk.org/?method_name=sfw_logs&auth_key='.$ct_key, $qdata, false);
			
			$result = json_decode($result);
			//Checking answer and truncate table, reset counter
			if(isset($result->data) && isset($result->data->rows))
				if($result->data->rows == count($data)){
					\Drupal::service('database')->query("TRUNCATE TABLE `{cleantalk_sfw_logs}`");
				}
		}
	}
}
?>
